@@ -1,4 +1,4 @@
-test_that("calc.ll produces correct results.", {
+test_that("calc_ll produces correct results.", {
 
     get_param_lengths_num <- function(param_lengths) {
         names_param_lengths <- c("mu","phi","rowc","col","rowc_col","rowc_cov","cov","colc","row","colc_row","colc_cov","rowc_colc")
@@ -12,12 +12,12 @@ test_that("calc.ll produces correct results.", {
     q <- 3
     RG <- 2
     z <- c(0.1,0.2,0.3,0.4,0.8,0.9)
-    ppr.m <- cbind(z, 1-z)
-    pi.v <- colMeans(ppr.m)
+    ppr_m <- cbind(z, 1-z)
+    pi_v <- colMeans(ppr_m)
 
     x <- c(0.7,0.9,0.2)
-    ppc.m <- cbind(x,1-x)
-    kappa.v <- colMeans(ppc.m)
+    ppc_m <- cbind(x,1-x)
+    kappa_v <- colMeans(ppc_m)
 
     mu <- c(-0.5,1)
     phi <- 0.2
@@ -43,7 +43,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu,phi,alpha_r), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -30.77587457, ignore_attr=TRUE, tolerance=1E-4)
@@ -51,7 +51,7 @@ test_that("calc.ll produces correct results.", {
     param_lengths_num <- get_param_lengths_num(c(q,q,RG,p,0,0,0,0,0,0,0,0))
     expect_equal(rcpp_Rclusterll(c(mu,phi,alpha_r,beta_j), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -35.08129788, ignore_attr=TRUE, tolerance=1E-4)
@@ -62,7 +62,7 @@ test_that("calc.ll produces correct results.", {
     gamma_rj <- c(-0.5,-1)
     expect_equal(rcpp_Rclusterll(c(mu,phi,alpha_r,beta_j,gamma_rj), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -37.2425604, ignore_attr=TRUE, tolerance=1E-4)
@@ -71,7 +71,7 @@ test_that("calc.ll produces correct results.", {
     gamma_rj <- c(-0.9,-0.1,0.4,0.9,1.2)
     expect_equal(rcpp_Rclusterll(c(mu,phi,gamma_rj), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -28.54661792, ignore_attr=TRUE, tolerance=1E-4)
@@ -80,13 +80,13 @@ test_that("calc.ll produces correct results.", {
     beta_c <- c(0.5)
     CG <- 2
     x <- c(0.7,0.9,0.2)
-    ppc.m <- cbind(x, 1-x)
-    kappa.v <- colMeans(ppc.m)
+    ppc_m <- cbind(x, 1-x)
+    kappa_v <- colMeans(ppc_m)
 
     param_lengths_num <- get_param_lengths_num(c(q,q,RG,0,0,0,0,CG,0,0,0,0))
     expect_equal(rcpp_Biclusterll(c(mu,phi,alpha_r,beta_c), model_num, ydf,
                                   rowcmm, colcmm, covmm,
-                                  ppr.m, ppc.m, pi.v, kappa.v, param_lengths = param_lengths_num,
+                                  ppr_m, ppc_m, pi_v, kappa_v, param_lengths = param_lengths_num,
                                   RG, CG, p, n, q, epsilon=1e-6,
                                   constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE, llc=NA),
                  -31.72322174, ignore_attr=TRUE, tolerance=1E-4)
@@ -97,7 +97,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Biclusterll(c(mu,phi,alpha_r,beta_c,gamma_rc), model_num, ydf,
                                   rowcmm, colcmm, covmm,
-                                  ppr.m, ppc.m, pi.v, kappa.v, param_lengths = param_lengths_num,
+                                  ppr_m, ppc_m, pi_v, kappa_v, param_lengths = param_lengths_num,
                                   RG, CG, p, n, q, epsilon=1e-6,
                                   constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE, llc=NA),
                  -33.35139077, ignore_attr=TRUE, tolerance=1E-4)
@@ -107,7 +107,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Biclusterll(c(mu,phi,gamma_rc), model_num, ydf,
                                   rowcmm, colcmm, covmm,
-                                  ppr.m, ppc.m, pi.v, kappa.v, param_lengths = param_lengths_num,
+                                  ppr_m, ppc_m, pi_v, kappa_v, param_lengths = param_lengths_num,
                                   RG, CG, p, n, q, epsilon=1e-6,
                                   constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE, llc=NA),
                  -29.3065552, ignore_attr=TRUE, tolerance=1E-4)
@@ -121,7 +121,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu,phi,beta_c), model_num, transp.ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppc.m, kappa.v, param_lengths = param_lengths_num,
+                                 ppc_m, kappa_v, param_lengths = param_lengths_num,
                                  CG, n, p, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -26.17120036, ignore_attr=TRUE, tolerance=1E-4)
@@ -130,7 +130,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu,phi,beta_c,alpha_i), model_num, transp.ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppc.m, kappa.v, param_lengths = param_lengths_num,
+                                 ppc_m, kappa_v, param_lengths = param_lengths_num,
                                  CG, n, p, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -21.493366, ignore_attr=TRUE, tolerance=1E-4)
@@ -144,8 +144,8 @@ test_that("calc.ll produces correct results.", {
     q <- 3
     RG <- 2
     z <- c(0.1,0.2,0.3,0.4,0.8,0.9)
-    ppr.m <- cbind(z, 1-z)
-    pi.v <- colMeans(ppr.m)
+    ppr_m <- cbind(z, 1-z)
+    pi_v <- colMeans(ppr_m)
 
     mu <- c(-0.5,1)
     phi <- 0.2
@@ -170,7 +170,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu_reparam,alpha_r), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -25.93596493, ignore_attr=TRUE, tolerance=1E-4)
@@ -178,7 +178,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu_reparam,alpha_r,beta_j), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -31.35665815, ignore_attr=TRUE, tolerance=1E-4)
@@ -188,7 +188,7 @@ test_that("calc.ll produces correct results.", {
     gamma_rj <- c(-0.5,-1)
     expect_equal(rcpp_Rclusterll(c(mu_reparam,alpha_r,beta_j,gamma_rj), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -33.29262377, ignore_attr=TRUE, tolerance=1E-4)
@@ -197,14 +197,14 @@ test_that("calc.ll produces correct results.", {
     beta_c <- c(0.5)
     CG <- 2
     x <- c(0.7,0.9,0.2)
-    ppc.m <- cbind(x, 1-x)
-    kappa.v <- colMeans(ppc.m)
+    ppc_m <- cbind(x, 1-x)
+    kappa_v <- colMeans(ppc_m)
 
     param_lengths_num <- get_param_lengths_num(c(q,0,RG,0,0,0,0,CG,0,0,0,0))
 
     expect_equal(rcpp_Biclusterll(c(mu_reparam,alpha_r,beta_c), model_num, ydf,
                                   rowcmm, colcmm, covmm,
-                                  ppr.m, ppc.m, pi.v, kappa.v, param_lengths = param_lengths_num,
+                                  ppr_m, ppc_m, pi_v, kappa_v, param_lengths = param_lengths_num,
                                   RG, CG, p, n, q, epsilon=1e-6,
                                   constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE, llc=NA),
                  -26.79095153, ignore_attr=TRUE, tolerance=1E-4)
@@ -215,7 +215,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Biclusterll(c(mu_reparam,alpha_r,beta_c,gamma_rc), model_num, ydf,
                                   rowcmm, colcmm, covmm,
-                                  ppr.m, ppc.m, pi.v, kappa.v, param_lengths = param_lengths_num,
+                                  ppr_m, ppc_m, pi_v, kappa_v, param_lengths = param_lengths_num,
                                   RG, CG, p, n, q, epsilon=1e-6,
                                   constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE, llc=NA),
                  -29.62326529, ignore_attr=TRUE, tolerance=1E-4)
@@ -229,12 +229,12 @@ test_that("calc.ll produces correct results.", {
     q <- 2
     RG <- 2
     z <- c(0.1,0.2,0.7,0.8)
-    ppr.m <- cbind(z, 1-z)
-    pi.v <- colMeans(ppr.m)
+    ppr_m <- cbind(z, 1-z)
+    pi_v <- colMeans(ppr_m)
     CG <- 2
     x <- c(0.7,0.9)
-    ppc.m <- cbind(x, 1-x)
-    kappa.v <- colMeans(ppc.m)
+    ppc_m <- cbind(x, 1-x)
+    kappa_v <- colMeans(ppc_m)
 
     mu <- c(-0.5)
     alpha_r <- -1
@@ -256,7 +256,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu,alpha_r), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -5.21102653113038, ignore_attr=TRUE, tolerance=1E-4)
@@ -265,7 +265,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu,alpha_r,beta_j), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -8.123555951, ignore_attr=TRUE, tolerance=1E-4)
@@ -273,7 +273,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu,alpha_r,beta_j,gamma_rj), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -9.06850841785471, ignore_attr=TRUE, tolerance=1E-4)
@@ -284,13 +284,13 @@ test_that("calc.ll produces correct results.", {
     q <- 2
     RG <- 2
     z <- c(0.1,0.2,0.7,0.8)
-    ppr.m <- cbind(z, 1-z)
-    pi.v <- colMeans(ppr.m)
+    ppr_m <- cbind(z, 1-z)
+    pi_v <- colMeans(ppr_m)
 
     CG <- 2
     x <- c(0.7,0.9)
-    ppc.m <- cbind(x, 1-x)
-    kappa.v <- colMeans(ppc.m)
+    ppc_m <- cbind(x, 1-x)
+    kappa_v <- colMeans(ppc_m)
 
     mu <- c(-0.5)
     alpha_r <- -1
@@ -334,7 +334,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu,alpha_r,rowc_cov_coef,cov_coef), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -6.049954084, ignore_attr=TRUE, tolerance=1E-4)
@@ -360,7 +360,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Rclusterll(c(mu,alpha_r,rowc_cov_coef,cov_coef), model_num, ydf,
                                  rowcmm, colcmm, covmm,
-                                 ppr.m, pi.v, param_lengths = param_lengths_num,
+                                 ppr_m, pi_v, param_lengths = param_lengths_num,
                                  RG, p, n, q, epsilon=1e-6,
                                  constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE),
                  -8.207088332, ignore_attr=TRUE, tolerance=1E-4)
@@ -381,7 +381,7 @@ test_that("calc.ll produces correct results.", {
 
     expect_equal(rcpp_Biclusterll(c(mu,alpha_r,colc_cov_coef), model_num, ydf,
                                   rowcmm, colcmm, covmm,
-                                  ppr.m, ppc.m, pi.v, kappa.v, param_lengths = param_lengths_num,
+                                  ppr_m, ppc_m, pi_v, kappa_v, param_lengths = param_lengths_num,
                                   RG, CG, p, n, q, epsilon=1e-6,
                                   constraint_sum_zero=TRUE, partial=TRUE, incomplete=FALSE, llc=NA),
                  -7.781711754, ignore_attr=TRUE, tolerance=1E-4)
@@ -389,7 +389,7 @@ test_that("calc.ll produces correct results.", {
     ## Binary INCOMPLETE log-likelihood =====
     expect_equal(rcpp_Biclusterll(c(mu,alpha_r,colc_cov_coef), model_num, ydf,
                      rowcmm, colcmm, covmm,
-                     ppr.m, ppc.m, pi.v, kappa.v, param_lengths = param_lengths_num,
+                     ppr_m, ppc_m, pi_v, kappa_v, param_lengths = param_lengths_num,
                      RG, CG, p, n, q, epsilon=1e-6,
                      constraint_sum_zero=TRUE, partial=TRUE, incomplete=TRUE, llc=NA),
                  -0.164418407, ignore_attr=TRUE, tolerance=1E-4)
